ferda_time = {
    0: "midnight snack",  # 12:00am
    50: "post midnight snack (lunch)",  # 12:50am
    145: "2nd dinner",  # 1:45am
    230: "unironic, actual dinner",  # 2:30am
    500: "pre-pre-breakfast (eaten during sleep)",  # 5:00am
    545: "1st snack (still asleep)",  # 5:45am
    630: "Musaharati / Breakfast Barbaque / Musahūr",  # 6:30am
    715: "pre-breakfast",  # 7:15am
    750: "breakfast",  # 7:50am
    900: "brunch",  # 9:00am
    1000: "2nd breakfast / zweites Frühstück",  # 10:00am
    1045: "bruncher",
    1111: "Elevenses",
    1145: "suncher",
    1205: "pre-lunch",  # 12:05pm
    1240: "ironic post-ironic unironic krabby patty bruncher",
    1320: "lunch (just a snack)",
    1405: "post lunch",
    1500: "Tiffin",  # 3:00pm
    1530: "post-ironic post-modernist post-lunch",
    1615: "pre-linner (2nd snack)",
    1700: "pina colada OR pre modernist mezcal shot",
    1715: "second post ironic unironic pre ironic breakfast",
    1822: "linner",  # 6:22pm
    1900: "dunch",
    2015: "dinner (if you're post-modernist, add Jiggs)",
    2110: "supper (~2nd suncher)",
    2210: "Siu Yeh",
    2300: "ler",  # 11:00pm
    2342: "post-linner",
    2352: "a krabby patty",  # 11:52pm
}
